Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/TurtleArt/taconstants.py
diff options
context:
space:
mode:
Diffstat (limited to 'TurtleArt/taconstants.py')
-rw-r--r--TurtleArt/taconstants.py9
1 files changed, 6 insertions, 3 deletions
diff --git a/TurtleArt/taconstants.py b/TurtleArt/taconstants.py
index ba0b5a7..9666573 100644
--- a/TurtleArt/taconstants.py
+++ b/TurtleArt/taconstants.py
@@ -103,6 +103,9 @@ class Color(object):
def __float__(self):
return float(int(self))
+ def get_number_string(self):
+ return str(int(self))
+
def __str__(self):
return str(self.name)
@@ -194,10 +197,10 @@ OLD_DOCK = ['and', 'or', 'plus', 'minus', 'division', 'product', 'remainder']
CONTENT_ARGS = ['show', 'showaligned', 'push', 'storein', 'storeinbox1',
'storeinbox2']
-PREFIX_DICTIONARY = {}
+MEDIA_BLOCK2TYPE = {} # map media blocks to media types
+
-# These blocks get a special skin
-BLOCKS_WITH_SKIN = []
+BLOCKS_WITH_SKIN = [] # These blocks get a special skin
PYTHON_SKIN = []